Module:    make-x-sockets
Synopsis:  Create the x-sockets library
Author:    Chris Double
Copyright: (C) 2000, Chris Double.  All rights reserved.
License:   See License.txt

define constant $intro-text = 
  "This application will copy the source to the socket library"
  "\nfrom a functional developer installation and apply a series"
  "\nof patches that allow the library to be extended to support"
  "\nnew protocols by other libraries. This is required for the"
  "\nSSL Socket library available at http://www.double.co.nz/dylan.";

define variable *source-directory* = "";
define variable *dest-directory* = "";
define variable *patch-directory* = "";


define frame <main-frame> (<wizard-frame>)
  pane introduction-text-pane (frame)
    make(<text-editor>, read-only?: #t, text: $intro-text);

  pane first-page-layout (frame)
    vertically()
      frame.introduction-text-pane
    end;

  pane first-page (frame)
    make(<wizard-page>, child: frame.first-page-layout);

  pane source-directory-pane (frame)
      make(<text-field>, 
           text: *source-directory*,
           value-changing-callback: method(gadget) 
                                      *source-directory* := gadget.gadget-value;
                                    end);

  pane source-browse-button-pane (frame)
      make(<push-button>, 
           label: "Browse",
           activate-callback: method(button)
                                let dir = choose-directory(owner: frame);
                                when(dir)
                                  frame.source-directory-pane.gadget-value := dir;
                                  *source-directory* := dir;
                                end;
                              end method);

  pane second-page-layout (frame)
    vertically()
      labelling("FD Socket Source Directory:") frame.source-directory-pane end;
      frame.source-browse-button-pane;
    end;

  pane second-page (frame)
    make(<wizard-page>, child: frame.second-page-layout);

  pane dest-directory-pane (frame)
      make(<text-field>, 
           text: *dest-directory*,
           value-changing-callback: method(gadget) 
                                      *dest-directory* := gadget.gadget-value;
                                    end);

  pane dest-browse-button-pane (frame)
      make(<push-button>, 
           label: "Browse",
           activate-callback: method(button)
                                let dir = choose-directory(owner: frame);
                                when(dir)
                                  frame.dest-directory-pane.gadget-value := dir;
                                  *dest-directory* := dir;
                                end;
                              end method);

  pane third-page-layout (frame)
    vertically()
      labelling("x-sockets destination Directory:") frame.dest-directory-pane end;
      frame.dest-browse-button-pane;
    end;

  pane third-page (frame)
    make(<wizard-page>, child: frame.third-page-layout);

  pane patch-directory-pane (frame)
      make(<text-field>, 
           text: *patch-directory*,
           value-changing-callback: method(gadget) 
                                      *patch-directory* := gadget.gadget-value;
                                    end);

  pane patch-browse-button-pane (frame)
      make(<push-button>, 
           label: "Browse",
           activate-callback: method(button)
                                let dir = choose-directory(owner: frame);
                                when(dir)
                                  frame.patch-directory-pane.gadget-value := dir;
                                  *patch-directory* := dir;
                                end;
                              end method);

  pane fourth-page-layout (frame)
    vertically()
      labelling("Patch Files Directory:") frame.patch-directory-pane end;
      frame.patch-browse-button-pane;
    end;

  pane fourth-page (frame)
    make(<wizard-page>, child: frame.fourth-page-layout);
    
  pages (frame)
    vector(frame.first-page, frame.second-page, frame.third-page, frame.fourth-page);

  keyword title: = "Socket Library Patcher";
  keyword width: = 350;
  keyword height: = 180;
end frame <main-frame>;

define method initialize(frame :: <main-frame>, #key) => ()
  next-method();
  frame-input-focus(frame) := frame.introduction-text-pane;
end method initialize;

define method main () => ()
  let frame = make(<main-frame>);
  when(start-dialog(frame))
    do-patch(*source-directory*, *dest-directory*, *patch-directory*);
  end;
  
end method main;

begin
  main();
end;
